#!/bin/sh
# Begin libsafe.sh


# Implements check_safe and log command.


# INCLUDE

include color

#
# === Begin of code
# 


prefix_log="( ${BLUE}log${NORMAL}  )${BLUE} == ${GRAY}"
suffix_log="${SET_SCOL}${BLUE} == ${NORMAL}"
prefix_shell_in="${YELLOW}<<${NORMAL} "
prefix_shell_out_std="${YELLOW}>>${NORMAL} "
prefix_shell_out_std_cont="${YELLOW} >${NORMAL} "
prefix_shell_out_errlvl="${BLUE}>>${NORMAL} "

prefix_shell_out_err="${RED}>>${NORMAL} "
sed_regexp_in="s/^/$prefix_shell_in/g"
sed_regexp_out_std="s/^/\\0$prefix_shell_out_std/g"
sed_regexp_out_err="s/^/\\0$prefix_shell_out_err/g"
sed_regexp_log_prefix="s/^/\\0$prefix_log/g"
sed_regexp_log_suffix="s/\$/$suffix_log\\0/g"


function log()
{
    echo "$*" | fold --width=64 -s | sed "{
$sed_regexp_log_suffix
$sed_regexp_log_prefix
}"
}

function check_safe()
{

    [ -z "$DEFAULT_TMP_PATH" ] && DEFAULT_TMP_PATH="/tmp"

    tmp_file_common=$DEFAULT_TMP_PATH/check_safe.common.$$

    error_caught=0
    command_line="$*"

    $command_line >& $tmp_file_common
    error_caught="$?"

    if [ "$error_caught" != "0" ]
    then
	echo "(${RED}failed${NORMAL}) -" $command_line
    else
	echo "(  ${GREEN}ok${NORMAL}  ) -" $command_line
    fi

    
    if [ -s $tmp_file_common ]
    then
	echo $(cat $tmp_file_common | fold --width=$[$COLUMNS - 3 ] -s | sed "{$sed_regexp_out_std
					    }")
    fi

    if [ "$error_caught" != "0" ]
    then
	echo -n "$prefix_shell_out_errlvl${BLUE}returned errorlevel [ "
	echo -n "${NORMAL}"
	echo -n $error_caught
	echo "${BLUE} ]${NORMAL}"
    fi

    rm -f $tmp_file_common
    return $error_caught
};

# End libsafe.sh
